@@ -81,7 +81,7 @@ class AppManager(object):
         if app:  # module_definition may not have a class that inherits from App.
             app.schema_name = possible_app_schema_name
             app.app_folder_path = possible_app_package_file_path
-            app.init_db_engine()
+            app._init_db_engine()
 
             LoadedApps.apps.pop(app.url_name, None)
             LoadedApps.apps[app.url_name] = app
@@ -110,7 +110,7 @@ class AppManager(object):
 
             TropofyDbMetaData.metadata.create_all(
                 bind=app.engine,
-                tables=app.get_orm_tables() + [
+                tables=app._get_orm_tables() + [
                     TropofyDbMetaData.metadata.tables[DynamicSchemaName.get_schema_qualified_table_name_if_using_schemas(AppDataSet.__tablename__)],
                     TropofyDbMetaData.metadata.tables[DynamicSchemaName.get_schema_qualified_table_name_if_using_schemas(DataSetVar.__tablename__)],
                     TropofyDbMetaData.metadata.tables[DynamicSchemaName.get_schema_qualified_table_name_if_using_schemas(SavedImageReference.__tablename__)],
