@@ -40,9 +40,9 @@ class App(object):
         self.developer_id = None
         self.step_groups = []
         self.app_folder_path = None  # Needs to be set dynamically after app created. This is to avoid params in constructor.
-        self._init_step_groups()
+        self.step_groups = self._get_gui()
 
-    def init_db_engine(self):
+    def _init_db_engine(self):
         """
         Initialise database engine connection string. Is dynamic to enable for SQLite and PSQL connections
         Note: Must be called after self.app_folder_path is set.
@@ -53,7 +53,7 @@ class App(object):
         :raise AttributeError: self.app_folder_path is not set prior to function call.
         """
         if self.app_folder_path is None:
-            raise AttributeError('self.app_folder_path must be set before App.init_db_engine is called.')
+            raise AttributeError('self.app_folder_path must be set before App._init_db_engine is called.')
 
         if App.global_sqla_engine:
             self.engine = App.global_sqla_engine
@@ -62,41 +62,38 @@ class App(object):
             self.engine = create_engine("sqlite:///" + engine_path)
 
 
-    def _init_step_groups(self):
+    def _get_gui(self, **kwargs):
         """Overide this to insert step groups before or after gui stepgroups"""
-        self._add_gui_stepgroups_with_steps()
+        return self.get_gui(**kwargs)
 
-    def _add_gui_stepgroups_with_steps(self):
-        [self.add_step_group(step_group) for step_group in self.get_gui()]
-
-    def get_name(self):
+    def get_name(self, **kwargs):
         raise NotImplementedError
 
-    def get_examples(self):
+    def get_examples(self, **kwargs):
         return {}
 
-    def get_example_app_names(self):
+    def _get_example_app_names(self):
         return [k for k in self.get_examples()]
 
-    def get_icon_url(self):
+    def get_icon_url(self, **kwargs):
         return ''
 
-    def get_page_title(self):
+    def get_page_title(self, **kwargs):
         return 'Tropofy'
 
-    def get_gui(self):
+    def get_gui(self, **kwargs):
         raise NotImplementedError
 
-    def get_home_page_content(self):
+    def get_home_page_content(self, **kwargs):
         return {}
 
-    def disable_forced_linear_workflow(self):
+    def disable_forced_linear_workflow(self, **kwargs):
         return False
 
-    def force_mfa_for_all_users(self):
+    def force_mfa_for_all_users(self, **kwargs):
         return False
 
-    def default_app_home_page_config(self):
+    def default_app_home_page_config(self, **kwargs):
         return {
             'content_app_name_header': '',
             'content_single_column_app_description': '',
@@ -116,36 +113,37 @@ class App(object):
             'content_row_4_col_1_content': ''
         }
 
-    def is_login_screen_default_create_account(self):
-        """At the login screen the default can be create account or sign in.
+    def is_login_screen_default_create_account(self, **kwargs):
+        """At the login screen the default can be create account or sign in. Overidden if App.app_allows_account_creation is false
 
         :rtype: bool
         """
         return True
 
-    def get_published_license_key(self):
+    def app_allows_account_creation(self, **kwargs):
+        """Determines whether the login page allows account creation. Defaults to True
+
+        :rtype: bool
+        """
+        return True
+
+    def app_allows_account_creation(self, **kwargs):
+        """Determines whether the login page allows account creation. Defaults to True
+
+        :rtype: bool
+        """
+        return True
+
+    def get_published_license_key(self, **kwargs):
         return ''
 
-    def get_home_page_configuration(self):
+    def _get_home_page_configuration(self):
         config = self.get_home_page_content()
         ret_config = self.default_app_home_page_config().copy()
         ret_config.update(config)
         return ret_config
 
-    def add_step_group(self, step_group):
-        self.step_groups.append(step_group)
-
-    def get_ordered_step_groups(self):
-        return sorted(self.step_groups, key=lambda step_group: step_group.id)
-
-    def get_all_widgets(self):
-        widgets = []
-        for group in self.step_groups:
-            for step in group.steps:
-                widgets.extend(step.widgets)
-        return widgets
-
-    def get_dependency_ordered_dict_of_tables_mapped_to_classes_for_app(self):
+    def _get_dependency_ordered_dict_of_tables_mapped_to_classes_for_app(self):
         """
         :returns: ordered dict of sqlalchemy.sql.schema.Table: to SQL ORM Class
         """
@@ -168,14 +166,14 @@ class App(object):
 
         return dependency_ordered_dict_of_tables_mapped_to_classes
 
-    def get_orm_tables(self):
-        return self.get_dependency_ordered_dict_of_tables_mapped_to_classes_for_app().keys()
+    def _get_orm_tables(self):
+        return self._get_dependency_ordered_dict_of_tables_mapped_to_classes_for_app().keys()
 
-    def get_data_set_as_excel_wb_string_repr(self, data_set):
+    def _get_data_set_as_excel_wb_string_repr(self, data_set):
         return read_write_xl.ExcelWriter.create_excel_string_repr(data_set)
 
-    def export_data_set(self, data_set):
-        response = Response(self.get_data_set_as_excel_wb_string_repr(data_set))
+    def _export_data_set(self, data_set):
+        response = Response(self._get_data_set_as_excel_wb_string_repr(data_set))
         file_name = "{name}.xlsx".format(name=data_set.name if data_set else 'export')
         response.headers['Content-Disposition'] = ("attachment; filename={file_name}".format(file_name=file_name))
         return response
@@ -183,24 +181,36 @@ class App(object):
     def get_path_of_file_in_app_folder(self, file_name):  # TODO: Should add docs to this. Is useful to be exposed.
         return os.path.join(self.app_folder_path, file_name)
 
-    def get_parameters(self):  # Returns list of parameters
+    def get_parameters(self, **kwargs):  # Returns list of parameters
         return []
 
-    def get_param(self, name):  # Returns parameter by name. Used by data_set to get parameter.
+    def _get_param(self, name):  # Returns parameter by name. Used by data_set to get parameter.
         return next(param for param in self.get_parameters() if param.name == name)
 
-    def _get_app_init_config(self, **kwargs):
-        """Return config options at the App level. These options are applied to the app on page load (not dynamic beyond this).
+    def _get_auto_load_data_set_id(self, **kwargs):
+        try:
+            return self.get_auto_load_data_set_id(**kwargs)
+        except:  # Fails to find auto load data_set_id - don't auto load.
+            return None
+
+    def get_auto_load_data_set_id(self, **kwargs):
+        """Skips the Getting Started page and loads the returned data_set id automatically.
+        You can use this functionality if your app does not manage data sets (i.e. derives
+        from App not AppWithDataSets) but instead is a view onto another apps data sets
+        :param authenticated_user: the email address of logged in user
+        :return: None, to not auto load data set, or id (int) of an AppDataSet to auto load it.
 
-        :returns: dict of form: {
-            'disableForcedLinearWorkflow': <bool>,  # Allows users to move to steps in any order.
-        }
         """
+        return None
+
+    def _get_app_init_config(self, **kwargs):
         return {
-            "disableForcedLinearWorkflow": self.disable_forced_linear_workflow()
+            "disableForcedLinearWorkflow": self.disable_forced_linear_workflow(),
+            'autoLoadDataSetId': self._get_auto_load_data_set_id(**kwargs)
         }
 
 
+
 class AppWithDataSets(App):
     """Provides an interface for writing a Tropofy App.
 
@@ -230,51 +240,53 @@ class AppWithDataSets(App):
         self.new_data_set_config_dict.update(self.get_new_dataset_config())
         App.__init__(self, config)
 
-    def _init_step_groups(self):
-        self._add_data_sets_step_group()
-        self._add_gui_stepgroups_with_steps()
+    def _get_gui(self, **kwargs):
+        data_sets_step_group = self._get_data_sets_step_group()
+        return [data_sets_step_group] + super(AppWithDataSets, self)._get_gui(**kwargs)
 
-    def _add_data_sets_step_group(self):
-        step_group = StepGroup(name="Getting Started")
-        step_group.add_step(Step(
-            name='Select Data Set',
-            hide_navigation=True,
-            widgets=[DataSets()],
-        ))
-        self.add_step_group(step_group)
+    def _get_data_sets_step_group(self):
+        return StepGroup(
+            name="Getting Started",
+            steps=[Step(
+                name='Select Data Set',
+                hide_navigation=True,
+                widgets=[DataSets()],
+            )]
+        )
 
-    def add_static_data_before_template_data_loaded(self, data_set):
+    def _add_static_data_before_template_data_loaded(self, data_set, **kwargs):
         """Populate data set with static data, before template data loaded.
 
         :rtype: None
         """
         pass
 
-    def get_new_dataset_config(self):
+    def get_new_dataset_config(self, **kwargs):
         """
-        Return a dict of config options for the new dataset form
-        keys:
-            has_none_template- default True, type bool
-            data_set_template_label- default "Template", type string
-        :rtype: dict
+        Return a dict of config options for the form on getting started under the 'New' option.
+
+        .. note:: Any keys that aren't included in the return dictionary will be set to their default values as described below.
+
+        :rtype: dict with preset keys defined below.
+
+        Details of return keys:
+
+        - "has_none_template": <bool, default True> This specifies whether when creating a new data_set, if there is an option to choose no template ('None')
+        - "data_set_template_label": <string, default "Template"> This changes the text above the first drop down.
+
+        .. code-block:: python
+
+            def get_new_dataset_config(self, **kwargs):
+                return {
+                    "has_none_template": False,
+                    "data_set_template_label": "Examples"
+                }
         """
         return {}
 
-    def _get_auto_load_data_set_id(self, **kwargs):
-        try:
-            return self.get_auto_load_data_set_id(**kwargs)
-        except:  # Fails to find auto load data_set_id - don't auto load.
-            return None
 
-    def get_auto_load_data_set_id(self, **kwargs):
-        """Skips the Getting Started page and loads the returned data_set id automatically.
-        :param authenticated_user: the email address of logged in user
-        :return: None, to not auto load data set, or id (int) of an AppDataSet to auto load it.
 
-        """
-        return None
-
-    def create_new_data_set_for_user(self, user_email, example_data_set_name, specific_name=''):
+    def _create_new_data_set_for_user(self, user_email, example_data_set_name, specific_name=''):
         data_set = AppDataSet(self, user_email)
         if specific_name:
             data_set.name = specific_name
@@ -286,11 +298,11 @@ class AppWithDataSets(App):
         data_set.init_parameters_with_defaults()  # Must be done here and not in AppDataSet.__init__ as requires data set to have ID.
 
         # TODO: load_master_data flag ?
-        self.add_static_data_before_template_data_loaded(data_set)
+        self._add_static_data_before_template_data_loaded(data_set)
 
         return data_set
 
-    def populate_data_set_from_template(self, data_set, data_set_template_name):
+    def _populate_data_set_from_template(self, data_set, data_set_template_name):
         if data_set_template_name and self.get_examples():
             try:
                 populate_example = self.get_examples().get(data_set_template_name)
@@ -301,7 +313,7 @@ class AppWithDataSets(App):
                 print("WARNING: An error occurred loading your example data set. See Traceback above.")
 
 
-    def get_name(self):
+    def get_name(self, **kwargs):
         """This function returns the name of the App as a string.
 
         .. literalinclude:: ../../../tropofy_example_apps/tutorials/tutorial_app_part_4.py
@@ -313,7 +325,7 @@ class AppWithDataSets(App):
         """
         raise NotImplementedError
 
-    def get_home_page_content(self):
+    def get_home_page_content(self, **kwargs):
         """(Optional) Define the contents of the apps default home page.
 
         :returns: Dictionary of {area_of_page:content_for_area} pairs
@@ -338,7 +350,7 @@ class AppWithDataSets(App):
         """
         return {}
 
-    def get_examples(self):
+    def get_examples(self, **kwargs):
         """Define example data sets that a user can load to demonstrate the Apps functionality.
 
         :returns: Dictionary of {example name:function} pairs, where each function populates an empty :class:`tropofy.app.AppDataSet`.
@@ -365,7 +377,7 @@ class AppWithDataSets(App):
         """
         return {}
 
-    def get_default_example_data_set_name(self):
+    def get_default_example_data_set_name(self, **kwargs):
         """(Optional) Set the name of the example data set that is created by default on first use of the app.
 
         :returns: String that matches a key in the dictionary returned by :func:`tropofy.app.AppWithDataSets.get_examples`.
@@ -376,7 +388,7 @@ class AppWithDataSets(App):
         """
         return None
 
-    def get_gui(self):
+    def get_gui(self, **kwargs):
         """This function defines the user interface for an App.
 
         An App consists of a list of Step Groups, where each Step Group is made up of Steps. A Step Group is represented by the
@@ -393,7 +405,7 @@ class AppWithDataSets(App):
         """
         raise NotImplementedError
 
-    def get_parameters(self):
+    def get_parameters(self, **kwargs):
         """Define parameters to be used in the app.
 
         :returns: list of :class:`tropofy.app.Parameter` mixins
@@ -411,7 +423,7 @@ class AppWithDataSets(App):
         """
         return []
 
-    def disable_forced_linear_workflow(self):
+    def disable_forced_linear_workflow(self, **kwargs):
         """(Optional) Disable linear workflow, enabling users to move between steps non-linearly.
 
         :returns: Default of False
@@ -419,7 +431,7 @@ class AppWithDataSets(App):
         """
         return False
 
-    def force_mfa_for_all_users(self):
+    def force_mfa_for_all_users(self, **kwargs):
         """(Optional) Force all users who log into app to use multi-factor authentication (MFA).
 
         If a user logs in who does not have MFA enabled, they will be redirected to the MFA setup page. They will have to setup MFA before they can access the apps content.
@@ -429,23 +441,14 @@ class AppWithDataSets(App):
         """
         return False
 
-    def get_page_title(self):
+    def get_page_title(self, **kwargs):
         """(Optional) Set the title for the webpage. In most browsers, used as text in the tab title. Default is 'Tropofy'.
 
         :type: str
         """
         return 'Tropofy'
 
-    def _get_app_init_config(self, **kwargs):
-        """Return config options at the App level. These options are applied to the app on page load (not dynamic beyond this).
 
-        :returns: dict of form: {
-            'disableForcedLinearWorkflow': <bool>,  # Allows users to move to steps in any order.
-        }
-        """
-        app_config = super(AppWithDataSets, self)._get_app_init_config(**kwargs)
-        app_config.update({'autoLoadDataSetId': self._get_auto_load_data_set_id(**kwargs)})
-        return app_config
 
 
 def make_safe_url_name(name):
