@@ -292,6 +292,7 @@ class AppDataSet(ORMBase):
         """
         return self.db_session().query(*args).filter_by(data_set_id=self.id)
 
+
     def save_image(self, name, image):
         """Saves a file to disk, and manages its lifetime and location..
 
@@ -368,7 +369,7 @@ class AppDataSet(ORMBase):
         :type name: str
         :param value: Value of parameter. Must satisfy any value restrictions specified on the parameter.
         """
-        param = self.app.get_param(name)
+        param = self.app._get_param(name)
         if param:
             if param.allowed_type:  # Will check correct type. Will also convert to correct type if able.
                 value = Validator.validate(value, param.allowed_type, name)
