@@ -24,4 +24,4 @@ class RoutingSession(Session):
             return threadlocal.get_current_request().app.engine
         return None
 
-DBSession = scoped_session(sessionmaker(class_=RoutingSession, extension=ZopeTransactionExtension(), expire_on_commit=False))
+DBSession = scoped_session(sessionmaker(class_=RoutingSession, extension=ZopeTransactionExtension(), expire_on_commit=False))  # TODO: remove , expire_on_commit=False. This messes with PACE though.
