@@ -13,6 +13,7 @@ or FITNESS FOR A PARTICULAR PURPOSE. See the license files for details.
 from operator import attrgetter
 
 import openpyxl
+from openpyxl import cell, formatting, exceptions
 from pyramid import threadlocal
 from openpyxl.writer.excel import save_virtual_workbook
 import datetime
@@ -47,12 +48,20 @@ class ClassWsMapping(ClassTabularDataMapping):
     :param objects: (Optional - default None) Specify mixins instead of dynamically generating them with ``get_objects``.
      A list of mixins of ``class_`` to be included in export. Will overide ``get_objects`` if value is not None.
     :type objects: list
+    :param styles: (Optional - default None) Dictionary of object properties (columns of sqla class) mapped to openpyxl.styles.Style objects. Applicable only to writing, not reading.
+    :type styles: dict
+    :param starting_cell: (Optional - default 'A1') Cell of worksheet to begin writing to, e.g. 'A1'.  Applicable only to writing, not reading.
+    :type starting_cell: str
 
     .. note:: To specify the order in which columns are written, use a ``collections.OrderedDict`` (Python built-in) for ``attribute_column_aliases``.
+    .. note:: For more information on openpyxl styles, refer to the `Openpyxl Docs <https://openpyxl.readthedocs.org/en/latest/styles.html>`_.
+
     """
 
-    def __init__(self, class_, ws_name, attribute_column_aliases, process_objects=None, get_objects=None, objects=None):
+    def __init__(self, class_, ws_name, attribute_column_aliases, process_objects=None, get_objects=None, objects=None, styles=None, starting_cell='A1'):
         self.ws_name = ws_name
+        self.styles=styles
+        self.starting_cell=starting_cell
         super(ClassWsMapping, self).__init__(class_, attribute_column_aliases, process_objects, get_objects, objects)
 
     @classmethod
@@ -72,7 +81,7 @@ class ClassWsMapping(ClassTabularDataMapping):
         app = app if app is not None else threadlocal.get_current_request().app
         class_ws_mappings = []
         if app:
-            tables_mapped_to_classes = app.get_dependency_ordered_dict_of_tables_mapped_to_classes_for_app()
+            tables_mapped_to_classes = app._get_dependency_ordered_dict_of_tables_mapped_to_classes_for_app()
             for table, class_ in tables_mapped_to_classes.iteritems():
                 if sqla_classes and class_ not in sqla_classes:  # Map all classes if none specified. Also only map classes in sqla_classes
                     class_ = None
@@ -137,7 +146,7 @@ class ClassWsMapping(ClassTabularDataMapping):
 class ExcelWriter(object):
     """Utility class for writing data to Microsoft Excel files."""
     @classmethod
-    def create_excel_string_repr(cls, data_set, ordered_class_ws_mappings=None):
+    def create_excel_string_repr(cls, data_set, ordered_class_ws_mappings=None, template_file_name_with_path=None, conditional_formats=None):
         """
         Create an Excel file as a string, which has a worksheet for each class in ordered_class_ws_mappings.
 
@@ -152,6 +161,11 @@ class ExcelWriter(object):
         :type data_set: :class:`tropofy.app.AppDataSet`
         :param ordered_class_ws_mappings: (Optional) Default None. If None is passed, automatic mappings will be made to do a 'full export' of all data in all SQLA ORM classes in the app.
         :type ordered_class_ws_mappings: list of :class:`tropofy.file_io.read_write_xl.ClassWsMapping`
+        :param template_file_name_with_path: (Optional) Default None. complete path/filename of a template if using one
+        :type template_file_name_with_path: str
+        :param conditional_formats: (Optional) Default None.  All conditional formats to apply to the mapped worksheets.
+        :type conditional_formats: list of :class:`tropofy.file_io.read_write_xl.ConditionalFormat`
+
         :return: str
         """
         if ordered_class_ws_mappings is None:
@@ -160,7 +174,7 @@ class ExcelWriter(object):
             if data_set is None:  # This would happen when creating Excel template - no objects to write
                 m.objects = []
             m.objects = m.objects if m.objects is not None else m.get_objects(data_set, m.class_)
-        wb = cls._create_excel_wb_from_class_mappings(ordered_class_ws_mappings)
+        wb = cls._create_excel_wb_from_class_mappings(ordered_class_ws_mappings, template_file_name_with_path, conditional_formats)
         return save_virtual_workbook(wb)
 
     @classmethod
@@ -196,32 +210,48 @@ class ExcelWriter(object):
         return cls._create_excel_wb_from_class_mappings(ordered_class_ws_mappings=ordered_class_ws_mappings)
 
     @classmethod
-    def _create_excel_wb_from_class_mappings(cls, ordered_class_ws_mappings):
+    def _create_excel_wb_from_class_mappings(cls, ordered_class_ws_mappings, template_file_name_with_path=None, conditional_formats=None):
         """Create an openpyxl in memory Excel workbook from a list of :class:`tropofy.file_io.read_write_xl.ClassWsMapping`.
 
         :param ordered_class_ws_mappings: Ordered list of :class:`tropofy.file_io.read_write_xl.ClassWsMapping`. Will be processed in this order.
         :type ordered_class_ws_mappings: ClassWsMapping list
+        :param template_file_name_with_path: (Optional) Default None. complete path/filename of a template if using one
+        :type template_file_name_with_path: str
+        :param conditional_formats: (Optional) Default None.  All conditional formats to apply to the mapped worksheets.
+        :type conditional_formats: list of :class:`tropofy.file_io.read_write_xl.ConditionalFormat`
         """
-        wb = openpyxl.Workbook()
+        if template_file_name_with_path:
+            wb = openpyxl.load_workbook(template_file_name_with_path)
+        else:
+            wb = openpyxl.Workbook()
         if wb.get_sheet_by_name('Sheet') is not None:
             wb.remove_sheet(wb.get_sheet_by_name('Sheet'))
 
         for mapping in ordered_class_ws_mappings:
-            worksheet = wb.create_sheet()
-            try:
-                worksheet.title = mapping.ws_name[:29]  # Excel ws names have a limit of 31 characters. Restrict to first 29 to allow excel to append numbers if names aren't unique.
-            except openpyxl.shared.exc.SheetTitleException:
-                raise openpyxl.shared.exc.SheetTitleException("Could not create > 100 worksheets with names with duplicate first 29 characters.")
-            col_names = mapping.required_column_names
-            if col_names:
-                for col in col_names:
-                    worksheet.cell(row=1, column=col_names.index(col)+1).value = col # new version of openpyxl does not like zero based cols and rows!
+            # if worksheet does not already exist in worksheet, create it
+            if mapping.ws_name[:29] not in [ws.title for ws in wb.worksheets]:
+                worksheet = wb.create_sheet()
+                try:
+                    worksheet.title = mapping.ws_name[:29]  # Excel ws names have a limit of 31 characters. Restrict to first 29 to allow excel to append numbers if names aren't unique.
+                except openpyxl.exceptions.SheetTitleException:
+                    raise openpyxl.exceptions.SheetTitleException("Could not create > 100 worksheets with names with duplicate first 29 characters.")
+            else:
+                worksheet = wb.get_sheet_by_name(mapping.ws_name[:29])
+            # col_names = mapping.required_column_names
+            starting_row = worksheet[mapping.starting_cell].row
+            starting_column = openpyxl.cell.column_index_from_string(worksheet[mapping.starting_cell].column)
+            col_keys = mapping.attribute_column_aliases.keys()
+            column_to_column_number_mapping = {}
+            if col_keys:
+                for col in col_keys:
+                    column_to_column_number_mapping[col] = starting_column+col_keys.index(col)
+                    worksheet.cell(row=starting_row, column=column_to_column_number_mapping[col]).value = mapping.attribute_column_aliases[col] # new version of openpyxl does not like zero based cols and rows!
 
                 for i, obj in enumerate(mapping.objects):
-                    for j, col_name in enumerate(col_names):
-                        excel_col = j + 1
+                    for j, col_key in enumerate(col_keys):
+                        col_num = starting_column + j
                         try:
-                            value = getattr(obj, mapping.get_attribute_from_column_name(col_name))
+                            value = getattr(obj, col_key)
                         except AttributeError:
                             print('Object in ClassWsMappingForExport.mixins does not match ClassWsMappingForExport object and col definition')
                             raise
@@ -231,16 +261,27 @@ class ExcelWriter(object):
                         if isinstance(value, datetime.datetime):
                             value = value.strftime("%H:%M %d/%m/%Y")  # otherwise we wont be able to read it back in
 
-                        row_num = i + 2  # Add one to row to skip col names header row and new version of openpyxl does not like zero based rows.
+                        row_num = starting_row + i + 1  # Add one to row to skip col names header row and new version of openpyxl does not like zero based rows.
                         if isinstance(value, basestring):  # Have to force string. Otherwise will automatically coerce to things. Eg scientific notation: '110E04' will save as 1100000.0
-                            worksheet.cell(row=row_num, column=excel_col).set_explicit_value(
+                            worksheet.cell(row=row_num, column=col_num).set_explicit_value(
                                 value=value,
                                 data_type=openpyxl.cell.Cell.TYPE_STRING
                             )
                         else:
-                            worksheet.cell(row=row_num, column=excel_col).value = value  # Add one to row to skip col names header row.
+                            worksheet.cell(row=row_num, column=col_num).value = value
+                        if mapping.styles is not None:
+                            worksheet.cell(row=row_num, column=col_num).style = mapping.styles[col_key]
+                if conditional_formats:
+                    applicable_conditional_formats = [cf for cf in conditional_formats if cf.applicable_column_worksheet_name == worksheet.title]
+                    cls._apply_conditional_formatting_rules(wb, applicable_conditional_formats, column_to_column_number_mapping, starting_row + 1, starting_row + 1 + len(mapping.objects))
+                    worksheet.conditional_formatting.setDxfStyles(wb)
         return wb
 
+    @classmethod
+    def _apply_conditional_formatting_rules(cls, wb, conditional_formats, column_to_column_number_mapping, first_row_of_data, last_row_of_data):
+        for cf in conditional_formats:
+            cf.apply_rule_to_worksheet(wb, column_to_column_number_mapping, first_row_of_data, last_row_of_data)
+
 
 class ExcelReader(object):
     """Utility class for reading data from Microsoft Excel files. Supports .xlsx, .xls, .xlsm formats.
@@ -415,10 +456,90 @@ class ExcelReader(object):
             return None
         if cell.ctype == xlrd.XL_CELL_BOOLEAN:
             return cell.value == 1
+        if cell.ctype == xlrd.XL_CELL_NUMBER:
+            # check to see if number is actually an integer - if so, return an integer; this stops values such as xxx.0 being returned
+            if (cell.value - int(cell.value) == 0.0):
+                return int(cell.value)
+
         return cell.value
 
 
+class ConditionalFormat():
+    """Conditional Formatting object to apply conditional formatting rules to a worksheet
+
+    :param applicable_column_worksheet_name: A user defined SQLAlchemy Python class
+    :type applicable_column_worksheet_name: str
+    :param applicable_column: the sqla class parameter name representing the column to apply the conditional format to
+    :type applicable_column: str
+    :param comparitor_column: the sqla class parameter name representing the column to compare the operator to
+    :type comparitor_column: str
+    :param operator: any key or value from the following dict:
+        {">": "greaterThan", ">=": "greaterThanOrEqual", "<": "lessThan", "<=": "lessThanOrEqual", "=": "equal", "==": "equal", "!=": "notEqual"}
+    :type operator: str
+    :param fill: The fill to apply if condition is true
+    :type fill: openpyxl PatternFill() or GradientFill() object
+    :param font: The font to apply if condition is true
+    :type font: openpyxl Font() object
+    :param border: The border to apply if condition is true
+    :type border: openpyxl Border() object
+    :param stopIfTrue: Stop processing further conditional formatting rules on a cell if condition is true
+    :type stopIfTrue: bool
+
+    .. note:: For more information on openpyxl Fill, Font and Border objects, refer to the `Openpyxl Docs <https://openpyxl.readthedocs.org/en/latest/styles.html>`_.
+    """
+
+    def __init__(self, applicable_column_worksheet_name, applicable_column, comparitor_column, operator, fill=None, font=None, border=None, stopIfTrue=True):
+
+        self.applicable_column_worksheet_name = applicable_column_worksheet_name
+        self.applicable_column = applicable_column
+        # self.comparitor_column_worksheet_name = comparitor_column_worksheet_name  todo: extend to allow comparitor column to be in different worksheet
+        self.comparitor_column = comparitor_column
+        self.operator = operator
+        self.fill = fill
+        self.font = font
+        self.border = border
+        self.stopIfTrue=stopIfTrue
+
+    def apply_rule_to_worksheet(self, workbook, column_to_column_number_mapping, first_row_of_data, last_row_of_data):
+        """
+        Applies the conditional formatting rule to the applicable worksheet in the workbook specified.
+
+        :param workbook: openpyxl Workbook() object to apply rule to
+        :param column_to_column_number_mapping: dictionary of column names to column numbers
+        :type column_to_column_number_mapping: dict(string: int)
+        :param first_row_of_data: first row of the data to apply conditional formatting rule
+        :type first_row_of_data: int
+        :param last_row_of_data: last row of the data to apply conditional formatting rule
+        :type last_row_of_data: int
+        """
+        ws = workbook.get_sheet_by_name(self.applicable_column_worksheet_name[:29])
+        applicable_column_letter = self.get_column_letter_from_integer_column_number(ws, column_to_column_number_mapping[self.applicable_column])
+        comparitor_column_letter = self.get_column_letter_from_integer_column_number(ws, column_to_column_number_mapping[self.comparitor_column])
+        applicable_range = applicable_column_letter + str(first_row_of_data) + ':' + applicable_column_letter + str(last_row_of_data)
+        formula_range = comparitor_column_letter + str(first_row_of_data)
+        rule = openpyxl.formatting.CellIsRule(
+                    operator=self.operator,
+                    formula=[formula_range],
+                    stopIfTrue=self.stopIfTrue,
+                    fill=self.fill,
+                    font=self.font,
+                    border=self.border,
+                )
+        ws.conditional_formatting.add(applicable_range, rule)
+
+    @classmethod
+    def get_column_letter_from_integer_column_number(cls, ws, column_number):
+        return ws.cell(row=1, column=column_number).column
+
+
 # ws helper function
 def _ws_headers_as_set(ws):
     headers = ws.row_values(0)
     return set([col.encode('ascii', 'ignore') for col in headers if col is not None])
+
+
+def work_book_as_text_string(excel_file_name_with_path):
+    wb = openpyxl.load_workbook(excel_file_name_with_path)
+    return save_virtual_workbook(wb)
+    wb = openpyxl.load_workbook(excel_file_name_with_path)
+    return save_virtual_workbook(wb)
\ No newline at end of file
