@@ -11,14 +11,16 @@ WITHOUT ANY WARRANTY; without even the implied warranty of MERCHANTABILITY
 or FITNESS FOR A PARTICULAR PURPOSE. See the license files for details.
 """
 
-from tropofy.database.db_manager import DbManager
 from tropofy.widgets import Form
 from tropofy.widgets import grid_widget
 from sqlalchemy.sql.expression import desc, or_, cast
 from sqlalchemy import String
-from sqlalchemy.orm import _mapper_registry
+from sqlalchemy import orm as sqla_orm
 from sqlalchemy.schema import CheckConstraint
 from tropofy.database import DBSession
+from tropofy.database.tropofy_orm import encryption
+
+from sqlalchemy.orm import sessionmaker
 
 
 class SimpleGrid(grid_widget.GridWidget):
@@ -41,9 +43,10 @@ class SimpleGrid(grid_widget.GridWidget):
     .. literalinclude:: ../../../tropofy/widgets/examples/widget_examples.py
         :pyobject: ConformingClass
     """
-    def __init__(self, source_class, editable=True, title=None, embedded_form_class=None, desc_sort_cols=None, widget_subscriptions=None):
+    def __init__(self, source_class, editable=True, title=None, embedded_form_class=None, desc_sort_cols=None, widget_subscriptions=None, default_ordered_col_name_sort_direction_tuples=None):
         self.source_class = source_class
         self.editable = editable
+        self.default_ordered_col_name_sort_direction_tuples = default_ordered_col_name_sort_direction_tuples
         super(SimpleGrid, self).__init__(
             title=title,
             embedded_form_class=embedded_form_class if embedded_form_class else SimpleGridCreateUpdateForm,
@@ -54,30 +57,47 @@ class SimpleGrid(grid_widget.GridWidget):
     def _get_type(self):
         return 'SimpleGrid'
 
-    def add_new_row(self, data, data_set_id):
-        edited_obj = DbManager.construct_object_and_add_to_db(source_class=self.source_class, data=data, data_set_id=data_set_id)
-        return edited_obj.as_json_data_row(self.get_grids_column_names())
+    def add_new_row(self, data, data_set_id=None, **kwargs):
+        """Assumes the data keys are a super set of the constructor arguments for the class type you are making
+        i.e. that the grids column headers are a super set of the constructor arguments"""
+        data.pop("data_set_id", None)
+        data.pop("id", None)
+        new_object = self.source_class(**data)
+        new_object.data_set_id = data_set_id
+        DBSession().add(new_object)
+        DBSession().flush()
 
-    def edit_row(self, data):
-        edited_obj = DbManager.update_object_in_db(source_class=self.source_class, data=data)
-        return edited_obj.as_json_data_row(self.get_grids_column_names())
+        return new_object.as_json_data_row(self.get_grids_column_names())
 
-    def delete_row(self, obj_id):
-        DbManager.delete_object_from_db(source_class=self.source_class, obj_id=obj_id)
+    def edit_row(self, data, **kwargs):
+        """Assumption that the names of the members of a class are equal to the keys you get in the
+        data object when editing, which in turn are the names of the columns in the grid, which
+        are a subset of the columns in the table hierachy for this object"""
+        existing_object = DBSession().query(self.source_class).filter_by(id=data['id']).one()
+
+        for k, v in data.iteritems():
+            if k not in ['id', 'data_set_id']:
+                setattr(existing_object, k, v)
+
+        DBSession().flush()
+        return existing_object.as_json_data_row(self.get_grids_column_names())
+
+    def delete_row(self, obj_id, **kwargs):
+        DBSession().delete(DBSession().query(self.source_class).filter_by(id=obj_id).one())
 
     def get_table_hierachy_from_inheritance_chain(self):
         full_class_hierachy = list(self.source_class.__bases__) + [self.source_class]
         return [class_type for class_type in full_class_hierachy if hasattr(class_type, "__table__")]
 
-    def get_grids_column_names(self):
+    def get_grids_column_names(self, **kwargs):
         return [col.name for class_type in self.get_table_hierachy_from_inheritance_chain() for col in class_type.__table__.columns]
 
-    def get_column_name_to_form_input_types(self):
+    def get_column_name_to_form_input_types(self, **kwargs):
         return {col.name: Form._get_input_type_from_python_type(col.type.python_type) for class_type in self.get_table_hierachy_from_inheritance_chain() for col in class_type.__table__.columns}
 
-    def get_filtered_rows(self, data_set, display_start, display_length, global_search_field, ordered_col_name_sort_direction_tuples):
+    def get_filtered_rows(self, data_set, display_start, display_length, global_search_field, ordered_col_name_sort_direction_tuples, **kwargs):
         try:
-            qry = self.get_qry_of_non_filtered_refresh_objects(data_set)
+            source_class, qry = self._get_qry_of_non_filtered_refresh_objects(data_set)
         except AttributeError:
             # TODO: Log that there was an attribute error on the refreshish
             return [], 0, 0
@@ -87,34 +107,61 @@ class SimpleGrid(grid_widget.GridWidget):
         if global_search_field:
             search_conditions = []
             do_not_search_on_cols = self.get_col_names_to_not_search_on(data_set)
-            for col_name in DbManager.sqla_cls_defined_column_names(self.source_class):
+            for col_name in _sqla_cls_defined_column_names(source_class):
                 if col_name not in do_not_search_on_cols:
                     search_conditions.append(
-                        cast(getattr(self.source_class, col_name), String).ilike('%' + global_search_field + '%')  # .ilike is case insensitive .like
+                        cast(getattr(source_class, col_name), String).ilike('%' + global_search_field + '%')  # .ilike is case insensitive .like
                     )
             qry = qry.filter(or_(*search_conditions))
                     
         total_records_after_filtering = qry.count()
         
         #Order cols
+        if self.default_ordered_col_name_sort_direction_tuples and not ordered_col_name_sort_direction_tuples:
+            ordered_col_name_sort_direction_tuples = self.default_ordered_col_name_sort_direction_tuples
         for col_name, direction in ordered_col_name_sort_direction_tuples:
             if direction == grid_widget.GridWidget.ASCENDING:
-                qry = qry.order_by(getattr(self.source_class, col_name))
+                qry = qry.order_by(getattr(source_class, col_name))
             elif direction == grid_widget.GridWidget.DESCENDING:
-                qry = qry.order_by(desc(getattr(self.source_class, col_name)))
+                qry = qry.order_by(desc(getattr(source_class, col_name)))
 
         #Reduce to num rows on grid page
         qry = qry.offset(display_start).limit(display_length)
         rows = [obj.as_json_data_row(self.get_grids_column_names()) for obj in qry]
+
+        qry.session.close()  # Required, as if using encryption, qry uses a session not management by zope transaction manager.
         return rows, total_records_before_filtering, total_records_after_filtering
 
-    def get_qry_of_non_filtered_refresh_objects(self, data_set):
-        """
-        :returns: SQLA qry object, that if executed, would return all mixins in the grid - unfiltered and unsorted.
-        
+    def _get_qry_of_non_filtered_refresh_objects(self, data_set, **kwargs):
+        result = self.get_qry_of_non_filtered_refresh_objects(data_set, **kwargs)
+        try:
+            if len(result) == 2:  # result is a tuple, expected to be (source_class, qry)
+                return result
+        except Exception as e:  # Only qry was returned, create tuple with source_class.
+            return self.source_class, result
+
+    def get_qry_of_non_filtered_refresh_objects(self, data_set, **kwargs):
+        """Get the sqla query that will return sqla orm objects unfiltered by grid.
+
+        :returns: Either:
+         - sqla qry object - that if executed would return all mixins in the grid - unfiltered and unsorted
+         - tuple of (<sqla_class>, sqla_qry_object (as in prev)). Use if sqla_class that qry is built off of is different to `self.source_class`.
+
         Assumes data_set exists.
         """
         if data_set and hasattr(self.source_class, 'data_set_id'):
+            if hasattr(self.source_class, '__decrypted_cls__') and self.source_class.__decrypted_cls__:
+                # Note: This only works for tables with FK's because SQLite doesn't enforce FK's by default.
+                # If it did, we'd need to delete the constraints or copy all data from joined table (for a heavily constraint db, this could recursively pull the whole db for every grid refresh).
+                # Can't drop the FK constraint, as SQLite doesn't support ALTER TABLE DROP CONSTRAINT.
+                # Easiest thing to do (even though somewhat implicit), is to rely on FK's not being enforced.
+                # Tropofy framework turns on FK enforcement in SQLite if it is the main DB being used. This is fine though, because this encryption process wouldn't be compatible with SQLite anyway.
+                in_memory_db_engine = encryption.orm_decrypt_data_to_new_in_memory_db(data_set, [self.source_class])
+
+                Session = sessionmaker(bind=in_memory_db_engine)
+                session = Session()
+                return self.source_class.d, session.query(self.source_class.d).filter_by(data_set_id=data_set.id)
+
             return data_set.query(self.source_class)
         raise AttributeError('SimpleGrid for source_class `%s` has no `data_set_id` column. SimpleGrid expects this. If not using data sets, extend SimpleGrid and overide `get_qry_of_non_filtered_refresh_objects`' % self.source_class.__name__)
 
@@ -169,7 +216,11 @@ class SimpleGridCreateUpdateForm(grid_widget.CreateUpdateForm):
 
 
 def _get_mapper_for_table(table):
-    for mapper in list(_mapper_registry):
+    for mapper in list(sqla_orm._mapper_registry):
         if table in mapper._all_tables:
             return mapper
-    return None
\ No newline at end of file
+    return None
+
+
+def _sqla_cls_defined_column_names(cls):
+    return [prop.key for prop in sqla_orm.class_mapper(cls).iterate_properties if isinstance(prop, sqla_orm.ColumnProperty)]
\ No newline at end of file
