@@ -75,10 +75,10 @@ class FoodServing(DataSetMixin):
 
 class ExecuteGurobiSolver(ExecuteFunction):
 
-    def get_button_text(self):
+    def get_button_text(self, **kwargs):
         return "Solve Diet Selection Problem"
 
-    def execute_function(self, data_set):
+    def execute_function(self, data_set, **kwargs):
         formulate_and_solve_diet_selection_problem(data_set)
 
 
@@ -132,13 +132,13 @@ class NutritionColumnChart(Chart):
 
 class GurobiDietSelectionApp(AppWithDataSets):
 
-    def get_name(self):
+    def get_name(self, **kwargs):
         return 'Gurobi Diet Selection Optimiser'
 
-    def get_examples(self):
+    def get_examples(self, **kwargs):
         return {"Demo data set from Gurobi": load_gurobi_data}
 
-    def get_gui(self):
+    def get_gui(self, **kwargs):
         step_group1 = StepGroup(name='Food and nutrition data')
         step_group1.add_step(Step(name='Enter your food selection', widgets=[SimpleGrid(Food)]))
         step_group1.add_step(Step(name='Enter your nutrition categories', widgets=[SimpleGrid(NutritionCategory)]))
@@ -159,10 +159,10 @@ class GurobiDietSelectionApp(AppWithDataSets):
 
         return [step_group1, step_group2, step_group3]
 
-    def get_icon_url(self):
+    def get_icon_url(self, **kwargs):
         return 'https://s3-ap-southeast-2.amazonaws.com/tropofy.com/static/css/img/tropofy_example_app_icons/gurobi_diet_tool.png'
 
-    def get_home_page_content(self):
+    def get_home_page_content(self, **kwargs):
         return {
             'content_app_name_header': '''
             <div>
