@@ -104,10 +104,10 @@ class ShiftsWorkedForEvenWorkings(DataSetMixin):
 
 class ExecuteGurobiSolver(ExecuteFunction):
 
-    def get_button_text(self):
+    def get_button_text(self, **kwargs):
         return "Solve Staff Rostering Problem"
 
-    def execute_function(self, data_set):
+    def execute_function(self, data_set, **kwargs):
         formulate_and_solve_staff_rostering_problem(data_set)
 
 
@@ -233,13 +233,13 @@ class Roster(Chart):
 
 class GurobiRosteringApp(AppWithDataSets):
 
-    def get_name(self):
+    def get_name(self, **kwargs):
         return 'Staff Rostering Optimiser'
 
-    def get_examples(self):
+    def get_examples(self, **kwargs):
         return {"Demo data set from Gurobi": load_gurobi_data}
 
-    def get_gui(self):
+    def get_gui(self, **kwargs):
         step_group1 = StepGroup(name='Enter your data')
         step_group1.add_step(Step(name='Enter your shift requirements', widgets=[SimpleGrid(ShiftRequirements)]))
         step_group1.add_step(Step(name='Enter your staff names and rates', widgets=[SimpleGrid(Staff)]))
@@ -269,10 +269,10 @@ class GurobiRosteringApp(AppWithDataSets):
 
         return [step_group1, step_group2, step_group3]
 
-    def get_icon_url(self):
+    def get_icon_url(self, **kwargs):
         return 'https://s3-ap-southeast-2.amazonaws.com/tropofy.com/static/css/img/tropofy_example_app_icons/staff_rostering.png'
 
-    def get_home_page_content(self):
+    def get_home_page_content(self, **kwargs):
         return {
             'content_app_name_header': '''
             <div>
