@@ -87,22 +87,22 @@ class ALSOAssemblyLineModelSequence(DataSetMixin):
 
 class ExecuteLocalSolver(ExecuteFunction):
 
-    def get_button_text(self):
+    def get_button_text(self, **kwargs):
         return "Solve Assembly Line Sequencing Problem"
 
-    def execute_function(self, data_set):
+    def execute_function(self, data_set, **kwargs):
         call_local_solver(data_set)
 
 
 class LocalSolverAssemblyLineSequencingOptimiser(AppWithDataSets):
 
-    def get_name(self):
+    def get_name(self, **kwargs):
         return 'LocalSolver Assembly Line Sequencing Optimiser'
 
-    def get_examples(self):
+    def get_examples(self, **kwargs):
         return {"Demo - The Tropesla assembly line": load_data_set}
 
-    def get_gui(self):
+    def get_gui(self, **kwargs):
         step_group1 = StepGroup(name='Enter your Data')
         step_group1.add_step(Step(name='Enter your model names', widgets=[SimpleGrid(ALSOModelName)]))
         step_group1.add_step(Step(name='Enter the options for models', widgets=[SimpleGrid(ALSOOptionName)]))
@@ -117,10 +117,10 @@ class LocalSolverAssemblyLineSequencingOptimiser(AppWithDataSets):
 
         return [step_group1, step_group2, step_group3]
 
-    def get_icon_url(self):
+    def get_icon_url(self, **kwargs):
         return 'https://s3-ap-southeast-2.amazonaws.com/tropofy.com/static/css/img/tropofy_example_app_icons/car_sequencing.png'
 
-    def get_home_page_content(self):
+    def get_home_page_content(self, **kwargs):
         return {
             'content_app_name_header': '''
             <div>
