@@ -76,10 +76,10 @@ class RegressionResult(DataSetMixin):
 
 
 class SimpleLinearRegressionWithR(AppWithDataSets):
-    def get_name(self):
+    def get_name(self, **kwargs):
         return "Simple Linear Regression With R"
 
-    def get_gui(self):
+    def get_gui(self, **kwargs):
         return [
             StepGroup(name='Input', steps=[Step(name='Data', widgets=[SimpleGrid(Data, editable=False)])]),
             StepGroup(name='Calculate', steps=[Step(name='Calculate', widgets=[ExecuteSolverFunction()])]),
@@ -90,13 +90,13 @@ class SimpleLinearRegressionWithR(AppWithDataSets):
             )]),
         ]
 
-    def get_examples(self):
+    def get_examples(self, **kwargs):
         return {"Demo Data set": load_example_1}
 
-    def get_icon_url(self):
+    def get_icon_url(self, **kwargs):
         return 'https://s3-ap-southeast-2.amazonaws.com/tropofy.com/static/css/img/tropofy_example_app_icons/linear_regression.png'
 
-    def get_home_page_content(self):
+    def get_home_page_content(self, **kwargs):
         return {
             'content_app_name_header': '''
             <div>
@@ -195,10 +195,10 @@ class RegressionResultChart(Chart):
 
 
 class ExecuteSolverFunction(ExecuteFunction):
-    def get_button_text(self):
+    def get_button_text(self, **kwargs):
         return "Calculate Linear Regression"
 
-    def execute_function(self, data_set):
+    def execute_function(self, data_set, **kwargs):
         """Interface to R with rpy2 to do a simple linear regression."""
         lm = robjects.r['lm']
         data = Data.get_all(data_set)
