@@ -43,7 +43,7 @@ class Scenario(DataSetMixin):
 
 
 class OutputPlot(StaticImage):
-    def get_file_path(self, data_set):
+    def get_file_path(self, data_set, **kwargs):
         return data_set.get_image_path('output.png')
 
 
@@ -73,7 +73,7 @@ class SelectScenario(Form):
                 disabled=len(options) == 0
             )]
 
-    def process_data(self, data, data_set):
+    def process_data(self, data, data_set, **kwargs):
         scenario_name = data.get('scenario')
         if scenario_name == 'None':
             return {
@@ -86,7 +86,7 @@ class SelectScenario(Form):
         data_set.set_var('scenario_name', scenario_name)
 
 class VictoryLossImage(StaticImage):
-    def get_file_path(self, data_set):
+    def get_file_path(self, data_set, **kwargs):
         zombie_victory = data_set.get_var('zombie_victory')
         if zombie_victory is not None:
             if zombie_victory:
@@ -96,10 +96,10 @@ class VictoryLossImage(StaticImage):
 
 
 class ZombieOutbreakApp(AppWithDataSets):
-    def get_name(self):
+    def get_name(self, **kwargs):
         return "Zombie Outbreak"
 
-    def get_gui(self):
+    def get_gui(self, **kwargs):
         return [
             StepGroup(
                 name='Input',
@@ -127,15 +127,15 @@ class ZombieOutbreakApp(AppWithDataSets):
             ),
         ]
 
-    def get_examples(self):
+    def get_examples(self, **kwargs):
         return {
             "Sample scenarios": load_sample_scenarios,
         }
 
-    def get_icon_url(self):
+    def get_icon_url(self, **kwargs):
         return 'https://s3-ap-southeast-2.amazonaws.com/tropofy.com/static/css/img/tropofy_example_app_icons/tombstone.png'
 
-    def get_home_page_content(self):
+    def get_home_page_content(self, **kwargs):
         return {
             'content_app_name_header': '''
             <div>
@@ -158,10 +158,10 @@ class ZombieOutbreakApp(AppWithDataSets):
 
 
 class CreatePlot(ExecuteFunction):
-    def get_button_text(self):
+    def get_button_text(self, **kwargs):
         return "Model the Apocalypse"
 
-    def execute_function(self, data_set):
+    def execute_function(self, data_set, **kwargs):
         scenario_name = data_set.get_var('scenario_name')
         try:
             scenario = data_set.query(Scenario).filter_by(name=scenario_name).one()
