@@ -227,7 +227,7 @@ class ElectedPieChart(Chart):
 
 class KMLMap(KMLMap):
 
-    def get_kml(self, data_set):
+    def get_kml(self, data_set, **kwargs):
         file_name = data_set.query(StaticKMLFileName).one().file_name
         f = open(os.path.join(os.path.split(os.path.realpath(__file__))[0], file_name), 'r')
         kml = f.read()
@@ -236,13 +236,13 @@ class KMLMap(KMLMap):
 
 class ElectionSummaryApp(AppWithDataSets):
 
-    def get_name(self):
+    def get_name(self, **kwargs):
         return 'Election Results Dashboard'
 
-    def get_examples(self):
+    def get_examples(self, **kwargs):
         return {"Demo Data for 2010": load_2010_data, "Data for 2007": load_2007_data, "Data for 2004": load_2004_data}
 
-    def get_gui(self):
+    def get_gui(self, **kwargs):
         step_group1 = StepGroup(name='Election Data')
         step_group1.add_step(Step(
             name='Dashboard',
@@ -263,10 +263,10 @@ class ElectionSummaryApp(AppWithDataSets):
         ))
         return [step_group1, step_group2]
 
-    def get_icon_url(self):
+    def get_icon_url(self, **kwargs):
         return 'https://s3-ap-southeast-2.amazonaws.com/tropofy.com/static/css/img/tropofy_example_app_icons/election_results_dashboard.png'
 
-    def get_home_page_content(self):
+    def get_home_page_content(self, **kwargs):
         return {
             'content_app_name_header': '''
             <div>
