@@ -57,7 +57,7 @@ class Line(DataSetMixin):
 
 
 class MyKMLMap(KMLMap):
-    def get_kml(self, data_set):
+    def get_kml(self, data_set, **kwargs):
 
         kml = Kml()
 
@@ -79,13 +79,13 @@ class MyKMLMap(KMLMap):
 
 class MyKMLGeneratorApp(AppWithDataSets):
 
-    def get_name(self):
+    def get_name(self, **kwargs):
         return "KML Generation"
 
-    def get_examples(self):
+    def get_examples(self, **kwargs):
         return {"Demo data for Brisbane": self.load_example_data_for_brisbane}
 
-    def get_gui(self):
+    def get_gui(self, **kwargs):
         step_group1 = StepGroup(name='Enter your data')
         step_group1.add_step(Step(name='Enter your locations', widgets=[SimpleGrid(Location)]))
         step_group1.add_step(Step(name='Enter your lines', widgets=[SimpleGrid(Line)]))
@@ -123,10 +123,10 @@ class MyKMLGeneratorApp(AppWithDataSets):
         lines.append(Line(locations[7].name, locations[8].name))
         data_set.add_all(lines)
 
-    def get_icon_url(self):
+    def get_icon_url(self, **kwargs):
         return 'https://s3-ap-southeast-2.amazonaws.com/tropofy.com/static/css/img/tropofy_example_app_icons/kml_generation.png'
     
-    def get_home_page_content(self):
+    def get_home_page_content(self, **kwargs):
         return {'content_app_name_header': '''
                 <div>
                 <span style="vertical-align: middle;">KML Generation</span>
