@@ -24,8 +24,8 @@ class MyLocation(DataSetMixin):
 
 
 class MyFirstApp(AppWithDataSets):
-    def get_name(self):
+    def get_name(self, **kwargs):
         return "Hello World"
 
-    def get_gui(self):
+    def get_gui(self, **kwargs):
         return [StepGroup(steps=[Step(widgets=[SimpleGrid(MyLocation)])])]
